@@ -3,5 +3,4 @@
 """Top-level package for Barril."""
 
 __author__ = """ESSS"""
-__email__ = 'foss@esss.co'
-__version__ = '0.1.0'
+__email__ = "foss@esss.co"
